package com.consultingwerk.plugins.smartunitlaunchconfig.ui.views.SmartUnitView;

import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyleRange;
import org.w3c.dom.Element;

public class Failure 
{
    private final Element error;
    
    /**
     * Construcor of the Failure class
     * @param error The xml-element containing error-info
     */
    public Failure (Element error)
    {
        this.error = error;
    }
    
    /**
     * Returns the Failures type
     * @return The Failures type
     */
    public String getType ()
    {
        return this.error.getAttribute("type");
    }
    
    /**
     * Returns the Failures message
     * @return The Failures message
     */
    protected String getMessage ()
    {
        return this.error.getAttribute("message");
    }
    
    /**
     * Returns the Failures stacktrace
     * @return The Failures stacktrace
     */
    protected String getStacktrace ()
    {
        return this.error.getTextContent();
    }
    
    /**
     * Combined message and stacktrace
     * @return The errors message and stacktrace
     */
    public String getText ()
    {
        String text;
        
        text = this.getMessage();
        text += this.newLines(2);
        text += this.getStacktrace();
        
        return text;
    }
    
    /**
     * Returns the style of the Failures error-text
     * @return The style of the Failures error-text
     */
    public StyleRange getStyle ()
    {
        StyleRange style = new StyleRange();
        
        style = new StyleRange();
        style.start = 0;
        style.length = this.getMessage().length();
        style.fontStyle = SWT.BOLD;
        
        return style;
    }
    
    /**
     * Returns a given amount of new lines
     * @param cnt The amount of new lines to return
     * @return Cnt new lines
     */
    private String newLines(int cnt)
    {
        String lines = "";
        for(int i = 0; i < cnt; i++)
            lines += System.lineSeparator();
        return lines;
    }
}
