package com.consultingwerk.plugins.smartunitlaunchconfig.ui.views.SmartUnitView;

import java.util.HashMap;
import org.eclipse.swt.custom.StyleRange;
import org.eclipse.swt.widgets.TreeItem;
import org.w3c.dom.Element;

public class Failures 
{
    private final HashMap<TreeItem, Failure> map;

    /**
     * Constructor for the Failures class
     */
    public Failures ()
    {
        map = new HashMap<TreeItem, Failure>();
    }
    
    /**
     * Adds an error to the list of failures
     * @param item The TreeItem for which to add the error
     * @param error The xml-element containing the error-info
     */
    public void addError (TreeItem item, 
                          Element error)
    {
        if(!this.map.containsKey(item))
            this.map.put(item, new Failure(error));
    }
    
    /**
     * Returns the error-type of a TreeItem
     * @param item The TreeItem to return the error-type for
     * @return The TreeItems error-type or an empty string
     */
    public String getType (TreeItem item)
    {
        if(this.map.containsKey(item))
            return this.map.get(item).getType();
        return "";
    }
    
    /**
     * Returns the error-text of a TreeItem
     * @param item The TreeItem to return the error-text for
     * @return The TreeItems error-text or an emtpty string
     */
    public String getText (TreeItem item)
    {
        if(this.map.containsKey(item))
            return this.map.get(item).getText();
        return "";
    }
    
    /**
     * The style to use for a TreeItems error-text
     * @param item The TreeItem to get the style for
     * @return The TreeItems error-text style
     */
    public StyleRange getStyle (TreeItem item)
    {
        if(this.map.containsKey(item))
            return this.map.get(item).getStyle();
        return new StyleRange();
    }
    
    /**
     * Empties the list of Failures
     */
    public void empty ()
    {
        this.map.clear();
    }
}
